pub fn capture_image_path(vpx_path: &Path, format: CaptureFormat) -> PathBufExpand description
Path where the playfield screenshot for the given table is written:
<table dir>/media/table.<ext>.
pub fn capture_image_path(vpx_path: &Path, format: CaptureFormat) -> PathBufPath where the playfield screenshot for the given table is written:
<table dir>/media/table.<ext>.